##########
Spruce-iri
##########

Spruce-iri is a Python library for manipulating Internationalized
Resource Identifiers (IRIs), Uniform Resource Identifiers (URIs), and
Uniform Resource Locators (URLs).  It is an extension of Python's
urllib_ and urlparse_ modules.


.. _urllib: http://docs.python.org/2/library/urllib

.. _urlparse: http://docs.python.org/2/library/urlparse
